@@ -27,7 +27,7 @@ def replace_escape_literals(matchobj):
     return ESCAPE_SEQUENCES.get(seq, seq)
 
 class JSONParser(Parser):
-    debugfile = 'parser.out'
+    # debugfile = 'parser.out'
     tokens = JSONLexer.tokens
 
 
@@ -150,14 +150,14 @@ class JSONParser(Parser):
         contents = p[0][1:-1]
         contents = re.sub(r'\\(\r\n|[\u000A\u000D\u2028\u2029])', '', contents)
         contents = re.sub(r'\\(.)', replace_escape_literals, contents)
-        return DoubleQuotedString(*contents)
+        return DoubleQuotedString(contents)
 
     @_("SINGLE_QUOTE_STRING")
     def single_quoted_string(self, p):
         contents = p[0][1:-1]
         contents = re.sub(r'\\(\r\n|[\u000A\u000D\u2028\u2029])', '', contents)
         contents = re.sub(r'\\(.)', replace_escape_literals, contents)
-        return SingleQuotedString(*contents)
+        return SingleQuotedString(contents)
 
     @_('double_quoted_string',
        'single_quoted_string')
